ADBC: Arrow Database Connectivity
ADBC is a set of APIs and libraries for Arrow-native access to databases. Execute SQL and Substrait queries, query database catalogs, and more, all using Arrow data to eliminate unnecessary data copies, speed up access, and make it more convenient to build analytical applications.
Read more about ADBC at https://arrow.apache.org/adbc/
The core library currently provides the basic types shared by vendor-specific drivers,
the driver manager, and the driver exporter.
Native Rust drivers
Native Rust drivers will implement the abstract API consisting of the traits:
For drivers implemented in Rust, using these will be more efficient and safe, since it avoids the overhead of going through C FFI.
Re-exports
pub use sync::*;
Modules
- constants
- Constants defined in
adbc.h - error
- Error, status and result types.
- options
- Various option and configuration types.
- schemas
- Schemas and data types that appear through ADBC.
- sync
Structs
- Partitioned
Result - A partitioned result set as returned by Statement::execute_partitions.
Constants
- LOAD_
FLAG_ ALLOW_ RELATIVE_ PATHS - LOAD_
FLAG_ DEFAULT - LOAD_
FLAG_ SEARCH_ ENV - LOAD_
FLAG_ SEARCH_ SYSTEM - LOAD_
FLAG_ SEARCH_ USER
Type Aliases
- Load
Flags - Partitions
- Each data partition is described by an opaque byte array and can be retrieved with Connection::read_partition.